@@ -1,17 +1,17 @@
 """
 Google App Engine support using User API
 """
-from __future__ import absolute_import
 
 from google.appengine.api import users
 
-from .base import BaseAuth
 from ..exceptions import AuthException
+from .base import BaseAuth
 
 
 class GoogleAppEngineAuth(BaseAuth):
     """GoogleAppengine authentication backend"""
-    name = 'google-appengine'
+
+    name = "google-appengine"
 
     def get_user_id(self, details, response):
         """Return current user id."""
@@ -22,11 +22,13 @@ class GoogleAppEngineAuth(BaseAuth):
     def get_user_details(self, response):
         """Return user basic information (id and email only)."""
         user = users.get_current_user()
-        return {'username': user.user_id(),
-                'email': user.email(),
-                'fullname': '',
-                'first_name': '',
-                'last_name': ''}
+        return {
+            "username": user.user_id(),
+            "email": user.email(),
+            "fullname": "",
+            "first_name": "",
+            "last_name": "",
+        }
 
     def auth_url(self):
         """Build and return complete URL."""
@@ -35,6 +37,6 @@ class GoogleAppEngineAuth(BaseAuth):
     def auth_complete(self, *args, **kwargs):
         """Completes login process, must return user instance."""
         if not users.get_current_user():
-            raise AuthException('Authentication error')
-        kwargs.update({'response': '', 'backend': self})
+            raise AuthException("Authentication error")
+        kwargs.update({"response": "", "backend": self})
         return self.strategy.authenticate(*args, **kwargs)
