@@ -25,7 +25,12 @@ class KeycloakOAuth2(BaseOAuth2):  # pylint: disable=abstract-method
 
     To set up, please take the following steps:
 
-    1. Create a new Keycloak client in the Clients section.
+    1. Create a new Keycloak client in the Clients section:
+
+        a. Choose the `Client ID` in the `General Settings` pane.
+
+        b. Select `Client authentication` and `Authorization` in the
+           `Capability config` pane.
 
     2. Configure the following parameters in the Client setup:
 
@@ -33,29 +38,34 @@ class KeycloakOAuth2(BaseOAuth2):  # pylint: disable=abstract-method
             Client ID (copy to settings as `KEY` value)
         Credentials >
             Client Authenticator >
-                Secret (copy to settings as `SECRET` value)
+                Use `Client Id and Secret` and copy the `Client secret` value
+                to settings as `SECRET` value
 
     3. For the tokens to work with the JWT setup the following configuration has
        to be made in Keycloak:
 
-        Settings >
-            Access Type >
-                confidential
-        Settings >
-            Fine Grain OpenID Connect Configuration >
-                User Info Signed
-        Response Algorithm >
-            RS256
-        Settings >
-            Fine Grain OpenID Connect Configuration >
-                Request Object Signature Algorithm > RS256
+        Advanced >
+            Fine grain OpenID Connect configuration >
+                User Info Signed Response Algorithm >
+                    RS256
+        Advanced >
+            Fine grain OpenID Connect configuration >
+                Request Object Signature Algorithm >
+                    RS256
 
-    4. Get the public key (copy to settings as `PUBLIC_KEY` value) to be used
+    4. Re-enable the audience (see https://issues.redhat.com/browse/KEYCLOAK-6638
+       for context):
+
+       Go to Client scopes > YOUR-CLIENT-ID-dedicated > Add mapper > Audience, pick
+       a name for the mapper and select the Client ID corresponding to your client
+       in `Included Client Audience`.
+
+    5. Get the public key (copy to settings as `PUBLIC_KEY` value) to be used
        with the backend:
 
         Realm Settings > Keys > Public key
 
-    5. Configure access token fields are configured via the Keycloak Client
+    6. Configure access token fields are configured via the Keycloak Client
        mappers:
 
         Clients > Client ID > Mappers
@@ -63,16 +73,19 @@ class KeycloakOAuth2(BaseOAuth2):  # pylint: disable=abstract-method
     They have to include at least the `ID_KEY` value and the dictionary keys
     defined in the `get_user_details` method.
 
-    6. Configure your web backend. Example setting values for Django settings
+    7. Configure your web backend. Example setting values for Django settings
        could be:
 
         SOCIAL_AUTH_KEYCLOAK_KEY = 'example'
         SOCIAL_AUTH_KEYCLOAK_SECRET = '1234abcd-1234-abcd-1234-abcd1234adcd'
-        SOCIAL_AUTH_KEYCLOAK_PUBLIC_KEY = 'pempublickeythatis2048bitsinbase64andhaseg392characters'
-        SOCIAL_AUTH_KEYCLOAK_AUTHORIZATION_URL = 'https://sso.example.com/auth/realms/example/protocol/openid-connect/auth'
-        SOCIAL_AUTH_KEYCLOAK_ACCESS_TOKEN_URL = 'https://sso.example.com/auth/realms/example/protocol/openid-connect/token'
+        SOCIAL_AUTH_KEYCLOAK_PUBLIC_KEY = \
+          'pempublickeythatis2048bitsinbase64andhaseg392characters'
+        SOCIAL_AUTH_KEYCLOAK_AUTHORIZATION_URL = \
+          'https://sso.com/auth/realms/example/protocol/openid-connect/auth'
+        SOCIAL_AUTH_KEYCLOAK_ACCESS_TOKEN_URL = \
+          'https://sso.com/auth/realms/example/protocol/openid-connect/token'
 
-    7. The default behaviour is to associate users via username field, but you
+    8. The default behaviour is to associate users via username field, but you
        can change the key with e.g.
 
             SOCIAL_AUTH_KEYCLOAK_ID_KEY = 'email'
@@ -82,30 +95,35 @@ class KeycloakOAuth2(BaseOAuth2):  # pylint: disable=abstract-method
     account association.
     """
 
-    name = 'keycloak'
-    ID_KEY = 'username'
-    ACCESS_TOKEN_METHOD = 'POST'
+    name = "keycloak"
+    ID_KEY = "username"
+    ACCESS_TOKEN_METHOD = "POST"
+    REDIRECT_STATE = False
 
     def authorization_url(self):
-        return self.setting('AUTHORIZATION_URL')
+        return self.setting("AUTHORIZATION_URL")
 
     def access_token_url(self):
-        return self.setting('ACCESS_TOKEN_URL')
+        return self.setting("ACCESS_TOKEN_URL")
 
     def audience(self):
-        return self.setting('KEY')
+        return self.setting("KEY")
 
     def algorithm(self):
-        return self.setting('ALGORITHM', default='RS256')
+        return self.setting("ALGORITHM", default="RS256")
 
     def public_key(self):
-        return '\n'.join([
-            '-----BEGIN PUBLIC KEY-----',
-            self.setting('PUBLIC_KEY'),
-            '-----END PUBLIC KEY-----',
-        ])
+        return "\n".join(
+            [
+                "-----BEGIN PUBLIC KEY-----",
+                self.setting("PUBLIC_KEY"),
+                "-----END PUBLIC KEY-----",
+            ]
+        )
 
-    def user_data(self, access_token, *args, **kwargs):  # pylint: disable=unused-argument
+    def user_data(
+        self, access_token, *args, **kwargs
+    ):  # pylint: disable=unused-argument
         """Decode user data from the access_token
 
         You can specialize this method to e.g. get information
@@ -123,11 +141,11 @@ class KeycloakOAuth2(BaseOAuth2):  # pylint: disable=abstract-method
     def get_user_details(self, response):
         """Map fields in user_data into Django User fields"""
         return {
-            'username': response.get('preferred_username'),
-            'email': response.get('email'),
-            'fullname': response.get('name'),
-            'first_name': response.get('given_name'),
-            'last_name': response.get('family_name'),
+            "username": response.get("preferred_username"),
+            "email": response.get("email"),
+            "fullname": response.get("name"),
+            "first_name": response.get("given_name"),
+            "last_name": response.get("family_name"),
         }
 
     def get_user_id(self, details, response):
