@@ -1,7 +1,7 @@
 from functools import wraps
 
-from .utils import partial_prepare
 from ..utils import PARTIAL_TOKEN_SESSION_NAME
+from .utils import partial_prepare
 
 
 def partial_step(save_to_session):
@@ -21,25 +21,36 @@ def partial_step(save_to_session):
     PARTIAL_TOKEN_SESSION_NAME (partial_pipeline_token) key when the
     save_to_session parameter is True.
     """
+
     def decorator(func):
         @wraps(func)
         def wrapper(strategy, backend, pipeline_index, *args, **kwargs):
-            current_partial = partial_prepare(strategy, backend, pipeline_index,
-                                              *args, **kwargs)
+            current_partial = partial_prepare(
+                strategy, backend, pipeline_index, *args, **kwargs
+            )
 
-            out = func(strategy=strategy,
-                       backend=backend,
-                       pipeline_index=pipeline_index,
-                       current_partial=current_partial,
-                       *args, **kwargs) or {}
+            out = (
+                func(
+                    strategy=strategy,
+                    backend=backend,
+                    pipeline_index=pipeline_index,
+                    current_partial=current_partial,
+                    *args,
+                    **kwargs
+                )
+                or {}
+            )
 
             if not isinstance(out, dict):
                 strategy.storage.partial.store(current_partial)
                 if save_to_session:
-                    strategy.session_set(PARTIAL_TOKEN_SESSION_NAME,
-                                         current_partial.token)
+                    strategy.session_set(
+                        PARTIAL_TOKEN_SESSION_NAME, current_partial.token
+                    )
             return out
+
         return wrapper
+
     return decorator
 
 
