@@ -2,11 +2,11 @@ from ..exceptions import AuthAlreadyAssociated, AuthException, AuthForbidden
 
 
 def social_details(backend, details, response, *args, **kwargs):
-    return {'details': dict(backend.get_user_details(response), **details)}
+    return {"details": dict(backend.get_user_details(response), **details)}
 
 
 def social_uid(backend, details, response, *args, **kwargs):
-    return {'uid': backend.get_user_id(details, response)}
+    return {"uid": backend.get_user_id(details, response)}
 
 
 def auth_allowed(backend, details, response, *args, **kwargs):
@@ -19,14 +19,15 @@ def social_user(backend, uid, user=None, *args, **kwargs):
     social = backend.strategy.storage.user.get_social_auth(provider, uid)
     if social:
         if user and social.user != user:
-            msg = 'This account is already in use.'
-            raise AuthAlreadyAssociated(backend, msg)
+            raise AuthAlreadyAssociated(backend)
         elif not user:
             user = social.user
-    return {'social': social,
-            'user': user,
-            'is_new': user is None,
-            'new_association': social is None}
+    return {
+        "social": social,
+        "user": user,
+        "is_new": user is None,
+        "new_association": social is None,
+    }
 
 
 def associate_user(backend, uid, user=None, social=None, *args, **kwargs):
@@ -41,11 +42,15 @@ def associate_user(backend, uid, user=None, social=None, *args, **kwargs):
             # Protect for possible race condition, those bastard with FTL
             # clicking capabilities, check issue #131:
             #   https://github.com/omab/django-social-auth/issues/131
-            return social_user(backend, uid, user, *args, **kwargs)
+            result = social_user(backend, uid, user, *args, **kwargs)
+            # Check if matching social auth really exists. In case it does
+            # not, the integrity error probably had different cause than
+            # existing entry and should not be hidden.
+            if not result["social"]:
+                raise
+            return result
         else:
-            return {'social': social,
-                    'user': social.user,
-                    'new_association': True}
+            return {"social": social, "user": social.user, "new_association": True}
 
 
 def associate_by_email(backend, details, user=None, *args, **kwargs):
@@ -61,7 +66,7 @@ def associate_by_email(backend, details, user=None, *args, **kwargs):
     if user:
         return None
 
-    email = details.get('email')
+    email = details.get("email")
     if email:
         # Try to associate accounts registered with the same email address,
         # only if it's a single object. AuthException is raised if multiple
@@ -71,18 +76,16 @@ def associate_by_email(backend, details, user=None, *args, **kwargs):
             return None
         elif len(users) > 1:
             raise AuthException(
-                backend,
-                'The given email address is associated with another account'
+                backend, "The given email address is associated with another account"
             )
         else:
-            return {'user': users[0],
-                    'is_new': False}
+            return {"user": users[0], "is_new": False}
 
 
 def load_extra_data(backend, details, response, uid, user, *args, **kwargs):
-    social = kwargs.get('social') or \
-             backend.strategy.storage.user.get_social_auth(backend.name, uid)
+    social = kwargs.get("social") or backend.strategy.storage.user.get_social_auth(
+        backend.name, uid
+    )
     if social:
-        extra_data = backend.extra_data(user, uid, response, details,
-                                        *args, **kwargs)
+        extra_data = backend.extra_data(user, uid, response, details, *args, **kwargs)
         social.set_extra_data(extra_data)
