@@ -2,9 +2,9 @@ from .legacy import BaseLegacyTest
 
 
 class EmailTest(BaseLegacyTest):
-    backend_path = 'social_core.backends.email.EmailAuth'
-    expected_username = 'foo'
-    response_body = 'email=foo@bar.com'
+    backend_path = "social_core.backends.email.EmailAuth"
+    expected_username = "foo"
+    response_body = "email=foo@bar.com"
     form = """
     <form method="post" action="{0}">
         <input name="email" type="text">
