@@ -1,7 +1,13 @@
 import base64
 
-from ..storage import UserMixin, NonceMixin, AssociationMixin, \
-    CodeMixin, PartialMixin, BaseStorage
+from ..storage import (
+    AssociationMixin,
+    BaseStorage,
+    CodeMixin,
+    NonceMixin,
+    PartialMixin,
+    UserMixin,
+)
 
 
 class BaseModel:
@@ -28,6 +34,7 @@ class User(BaseModel):
         self.id = User.next_id()
         self.username = username
         self.email = email
+        self.first_name = None
         self.password = None
         self.slug = None
         self.social = []
@@ -118,9 +125,11 @@ class TestUserSocialAuth(UserMixin, BaseModel):
 
     @classmethod
     def get_social_auth_for_user(cls, user, provider=None, id=None):
-        return [usa for usa in user.social
-                if provider in (None, usa.provider) and
-                id in (None, usa.id)]
+        return [
+            usa
+            for usa in user.social
+            if provider in (None, usa.provider) and id in (None, usa.id)
+        ]
 
     @classmethod
     def create_social_auth(cls, user, uid, provider):
@@ -147,6 +156,15 @@ class TestNonce(NonceMixin, BaseModel):
         TestNonce.cache[server_url] = nonce
         return nonce
 
+    @classmethod
+    def get(cls, server_url, salt):
+        return TestNonce.cache[server_url]
+
+    @classmethod
+    def delete(cls, nonce):
+        server_url = nonce.server_url
+        del TestNonce.cache[server_url]
+
 
 class TestAssociation(AssociationMixin, BaseModel):
     NEXT_ID = 1
@@ -164,8 +182,7 @@ class TestAssociation(AssociationMixin, BaseModel):
     def store(cls, server_url, association):
         assoc = TestAssociation.cache.get((server_url, association.handle))
         if assoc is None:
-            assoc = TestAssociation(server_url=server_url,
-                                    handle=association.handle)
+            assoc = TestAssociation(server_url=server_url, handle=association.handle)
         assoc.secret = base64.encodebytes(association.secret)
         assoc.issued = association.issued
         assoc.lifetime = association.lifetime
@@ -185,8 +202,7 @@ class TestAssociation(AssociationMixin, BaseModel):
 
     @classmethod
     def remove(cls, ids_to_delete):
-        assoc = filter(lambda a: a.id in ids_to_delete,
-                       TestAssociation.cache.values())
+        assoc = filter(lambda a: a.id in ids_to_delete, TestAssociation.cache.values())
         for a in list(assoc):
             TestAssociation.cache.pop((a.server_url, a.handle), None)
 
